@@ -2,8 +2,8 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2018 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2018 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2020 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2020 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -92,10 +92,30 @@ class LabTest(ModelSQL, ModelView):
     validation_date = fields.DateTime('Validated on', readonly=True,
         states = STATES )
 
+    historize = fields.Boolean("Historize",
+                    states = STATES,
+                    depends=['pathology'],
+                    help='If this flag is set'
+                    ' the a new health condition will be added'
+                    ' to the patient history.'
+                    ' Unset it if this lab test is in the context'
+                    ' of a pre-existing condition of the patient.'
+                    ' The condition will be created when the lab test'
+                    ' is confirmed and validated')
+
     @staticmethod
     def default_state():
         return 'draft'
 
+    @staticmethod
+    def default_historize():
+        return False
+
+    @fields.depends('pathology')
+    def on_change_with_historize(self):
+        if (self.pathology):
+            return True
+
     @classmethod
     def __setup__(cls):
         super(LabTest, cls).__setup__()
@@ -176,6 +196,13 @@ class LabTest(ModelSQL, ModelView):
         if (document.patient.name.federation_account):
             cls.create_lab_pol (document)
 
+        # Create Health condition to the patient
+        # if there is a confirmed pathology associated and
+        # validated to the lab test result
+        # The flag historize must also be set
+        if (document.pathology and document.historize):
+            cls.create_health_condition (document)
+
     @classmethod
     def get_serial(cls,document):
 
@@ -241,6 +268,27 @@ class LabTest(ModelSQL, ModelView):
                 'invisible': Not(Eval('state') == 'validated'),
                 })]
 
+    @classmethod
+    def create_health_condition(cls, lab_info):
+        """ Create the health condition when specified and 
+            validated in the lab test
+        """
+        HealthCondition = Pool().get('gnuhealth.patient.disease')
+        health_condition = []
+
+        vals = {
+            'name': lab_info.patient.id,
+            'pathology': lab_info.pathology,
+            'diagnosed_date': lab_info.date_analysis.date(),
+            'lab_confirmed': True,
+            'lab_test': lab_info.id,
+            'extra_info': lab_info.diagnosis,
+            'healthprof': lab_info.requestor
+            }
+
+        health_condition.append(vals)
+        HealthCondition.create(health_condition)
+
 
     @classmethod
     def create_lab_pol(cls,lab_info):
